" Vim Keymap file for Vietnamese through Telex method
" Maintainer: Raphael McSinyx <vn.mcsinyx@gmail.com>
" Last Change: 2016-06-13

scriptencoding utf-8

let b:keymap_name = "vi"

loadkeymap

A\\	A
AF	À
AS	Á
AR	Ả
AX	Ã
AJ	Ạ

AW	Ă
AW\\	Ă
AWF	Ằ
AWS	Ắ
AWR	Ẳ
AWX	Ẵ
AWJ	Ặ

AA	Â
AA\\	Â
AAF	Ầ
AAS	Ấ
AAR	Ẩ
AAX	Ẫ
AAJ	Ậ

D\\	D
DD	Đ

E	E
E\\	E
EF	È
ES	É
ER	Ẻ
EX	Ẽ
EJ	Ẹ

EE	Ê
EE\\	Ê
EEF	Ề
EES	Ế
EER	Ể
EEX	Ễ
EEJ	Ệ

I\\	I
IF	Ì
IS	Í
IR	Ỉ
IX	Ĩ
IJ	Ị

O\\	O
OF	Ò
OS	Ó
OR	Ỏ
OX	Õ
OJ	Ọ

OO	Ô
OO\\	Ô
OOF	Ồ
OOS	Ố
OOR	Ổ
OOX	Ỗ
OOJ	Ộ

OW	Ơ
OW\\	Ơ
OWF	Ờ
OWS	Ớ
OWR	Ở
OWX	Ỡ
OWJ	Ợ

U\\	U
UF	Ù
US	Ú
UR	Ủ
UX	Ũ
UJ	Ụ

UW	Ư
UW\\	Ư
UWF	Ừ
UWS	Ứ
UWR	Ử
UWX	Ữ
UWJ	Ự

Y\\	Y
YF	Ỳ
YS	Ý
YR	Ỷ
YX	Ỹ
YJ	Ỵ

a\\	a
af	à
as	á
ar	ả
ax	ã
aj	ạ

aw	ă
aw\\	ă
awf	ằ
aws	ắ
awr	ẳ
awx	ẵ
awj	ặ

aa	â
aa\\	â
aaf	ầ
aas	ấ
aar	ẩ
aax	ẫ
aaj	ậ

d\\	d
dd	đ

e\\	e
ef	è
es	é
er	ẻ
ex	ẽ
ej	ẹ

ee	ê
ee\\	ê
eef	ề
ees	ế
eer	ể
eex	ễ
eej	ệ

i\\	i
if	ì
is	í
ir	ỉ
ix	ĩ
ij	ị

o\\	o
of	ò
os	ó
or	ỏ
ox	õ
oj	ọ

oo	ô
oo\\	ô
oof	ồ
oos	ố
oor	ổ
oox	ỗ
ooj	ộ

ow	ơ
ow\\	ơ
owf	ờ
ows	ớ
owr	ở
owx	ỡ
owj	ợ

u\\	u
uf	ù
us	ú
ur	ủ
ux	ũ
uj	ụ

uw	ư
uw\\	ư
uwf	ừ
uws	ứ
uwr	ử
uwx	ữ
uwj	ự

y\\	y
yf	ỳ
ys	ý
yr	ỷ
yx	ỹ
yj	ỵ
