" Maintainer: Štěpán Němec <stepnem@gmail.com>
" Last Changed: Fri 25 Jun 2010 22:08:43 CEST

let b:keymap_name = "czech"

loadkey
0	é
9	í
8	á
7	ý
6	ž
5	ř
4	č
3	š
2	ě
1	+
`	;
)	0
(	9
*	8
&	7
^	6
%	5
$	4
#	3
@	2
!	1
]	)
}	(
[	ú
{	/
'	§
\"	!
;	ů
:	"
/	-
?	_
>	:
<	?
|	'
~u	ů
~U	Ů
\\a	ä
\\e	ë
\\i	ï
\\o	ö
\\u	ü
\\z	ÿ
\\A	Ä
\\E	Ë
\\I	Ï
\\O	Ö
\\U	Ü
\\Z	Ÿ
=a	á
=e	é
=i	í
=o	ó
=u	ú
=z	ý
=A	Á
=E	É
=I	Í
=O	Ó
=U	Ú
=Z	Ý
+c	č
+d	ď
+e	ě
+n	ň
+r	ř
+s	š
+t	ť
+y	ž
+C	Č
+D	Ď
+E	Ě
+N	Ň
+R	Ř
+S	Š
+T	Ť
+Y	Ž
y	z
Y	Z
z	y
Z	Y
